@@ -16,8 +16,8 @@ nparncpt.sqp = function (tstat, df, penalty=c('3rd.deriv','2nd.deriv','1st.deriv
     penalty=match.arg(penalty)
     solver.package=switch(solver, solve.QP='limSolve', ipop='kernlab', lsei='limSolve',LowRankQP='LowRankQP'
     )
-    loadOrInstall(solver.package)
-    loadOrInstall("Matrix")
+    #loadOrInstall(solver.package)
+    #loadOrInstall("Matrix")
     if (K<=0 || length(K)!=1) stop("K should be a positive integer")
     if (any(lambdas<0)) stop("lambdas should be a vector of positive numbers")
     lambdas=sort(lambdas)
@@ -95,7 +95,7 @@ nparncpt.sqp = function (tstat, df, penalty=c('3rd.deriv','2nd.deriv','1st.deriv
         if(approx){
             bl.approx=b.approx/Lik
             h0l=h0.i/Lik
-            blh0l=matrix(as.vector(crossprod(bl.approx, h0l)),K,K)
+            blh0l=matrix(as(crossprod(bl.approx, h0l),'vector'),K,K)
             crossprod.term=as.matrix(crossprod(bl.approx))+drop(crossprod(h0l))-blh0l-t(blh0l)
         }else{
             bi.lik=b.i/Lik
@@ -113,7 +113,7 @@ nparncpt.sqp = function (tstat, df, penalty=c('3rd.deriv','2nd.deriv','1st.deriv
         cbind(diag(1,length(thetas)),-1)
     }
     Amat=grad.C(numeric(K)) ## this is the A matrix for quadprog::solve.QP, i.e., t(A)%*%theta>=theta0 linear constraints
-                            ## for limSolve::lsei, this is t(G)
+                            ## for limSolve::lsei(, this is t(G)
 
     adjust.pi0=function(thetas){
         obj=function(r)NPLL(r*thetas)
@@ -123,7 +123,7 @@ nparncpt.sqp = function (tstat, df, penalty=c('3rd.deriv','2nd.deriv','1st.deriv
 
     sqp=function(thetas, conv.f=1e-10, verbose=FALSE, maxiter=1e3) { ## thetas is a starting value
         ## not a general solver; instead, designed for this problem per se
-        ## depends on solver, grad.NPLL, hess.NPLL, Matrix:::nearPD, Amat, C.fctn
+        ## depends on solver, grad.NPLL, hess.NPLL, nearPD, Amat, C.fctn
 
         npll.last=Inf
         niter=1
@@ -151,14 +151,14 @@ nparncpt.sqp = function (tstat, df, penalty=c('3rd.deriv','2nd.deriv','1st.deriv
                         tmpA=try(solve.QP(Dmat,dvec,Amat=Amat,bvec)$solution, silent=TRUE)
                         if(class(tmpA)=='try-error'){ # solver='lsei'
                             tmpA=chol(Dmat); tmpB=.5*drop(forwardsolve(t(tmpA), dvec)); 
-                            lsei(A=tmpA, B=tmpB, E=matrix(0,0,K), F=numeric(0), G=t(Amat), H=bvec, 
+                            limSolve::lsei(A=tmpA, B=tmpB, E=matrix(0,0,K), F=numeric(0), G=t(Amat), H=bvec, 
                                  Wx=NULL, Wa=NULL, type=1)$X
                         }else tmpA
                    }else if (solver=='lsei') {
                         tmpA=chol(Dmat); tmpB=.5*drop(forwardsolve(t(tmpA), dvec)); 
-#                        lsei(A=tmpA, B=tmpB, E=matrix(0,1,K), F=0, G=t(Amat), H=bvec, 
+#                        limSolve::lsei(A=tmpA, B=tmpB, E=matrix(0,1,K), F=0, G=t(Amat), H=bvec, 
 #                             Wx=NULL, Wa=NULL, type=1)$X
-                        lsei(A=tmpA, B=tmpB, E=matrix(0,0,K), F=numeric(0), G=t(Amat), H=bvec, 
+                        limSolve::lsei(A=tmpA, B=tmpB, E=matrix(0,0,K), F=numeric(0), G=t(Amat), H=bvec, 
                              Wx=NULL, Wa=NULL, type=1)$X
                    }else if (solver=='ipop') {  ## not working well ## the R translation of the LOQO code is not very honest
                         tmpA=ipop(c=-dvec, H=Dmat, A=t(Amat), b=bvec, l=rep(-1,K), u=rep(1,K), r=rep(1e6,K+1),verb=verbose)
@@ -253,7 +253,7 @@ nparncpt.sqp = function (tstat, df, penalty=c('3rd.deriv','2nd.deriv','1st.deriv
 #        browser()
         tmp=NPLL(sqp.fit[i,],FALSE)
         nics[i]=2*(sum(tmp))+IC.fact*enps[i]
-        nic.sd[i]=sd(tmp)*sqrt(G)
+        nic.sd[i]=sd(drop(tmp))*sqrt(G)
         pi0s[i]=1-sum(sqp.fit[i,])
     }
 
@@ -479,7 +479,7 @@ grad.C=function(thetas){  ## grad.C^TRUE thetas + C >=0
 Amat=grad.C(numeric(K))
     
 sqp=function(thetas, conv.f=1e-10, fnscale, verbose=TRUE) {
-loadOrInstall("quadprog")
+#loadOrInstall("quadprog")
   npll.last=Inf
   repeat{
 
@@ -607,7 +607,7 @@ for(i in rev(seq(along=nics))){
     enps[i]=enp(sqp.fit)
     tmp=NPLL(sqp.fit,FALSE)
     nics[i]=sum(tmp)+enps[i]
-    nic.sd[i]=sd(tmp)*sqrt(G)
+    nic.sd[i]=sd(drop(tmp))*sqrt(G)
     pi0s[i]=1-sum(sqp.fit)
     hist(ncps,pr=TRUE,xlim=c(min(tstat),max(tstat)),br=40,sub=lambda,main=enps[i]); rug(mus); 
     curve(d.ncp(x, sqp.fit/sum(sqp.fit)), min(tstat),max(tstat),100,add=TRUE,col=4,lwd=2)
